@@ -7,6 +7,7 @@ class Instruments(Enum):
     BEDROCK = "bedrock"
     CHROMA = "chroma"
     COHERE = "cohere"
+    CREW = "crew"
     GOOGLE_GENERATIVEAI = "google_generativeai"
     GROQ = "groq"
     HAYSTACK = "haystack"
@@ -31,3 +32,4 @@ class Instruments(Enum):
     VERTEXAI = "vertexai"
     WATSONX = "watsonx"
     WEAVIATE = "weaviate"
+    MCP = "mcp"
