@@ -61,6 +61,7 @@ class TracerWrapper(object):
     headers: Dict[str, str] = {}
     __tracer_provider: TracerProvider = None
     __image_uploader: ImageUploader = None
+    __disabled: bool = False
 
     def __new__(
         cls,
@@ -233,6 +234,9 @@ class TracerWrapper(object):
 
     @classmethod
     def verify_initialized(cls) -> bool:
+        if cls.__disabled:
+            return False
+
         if hasattr(cls, "instance"):
             return True
 
@@ -246,6 +250,10 @@ class TracerWrapper(object):
         print(Fore.RESET)
         return False
 
+    @classmethod
+    def set_disabled(cls, disabled: bool) -> None:
+        cls.__disabled = disabled
+
     def flush(self):
         self.__spans_processor.force_flush()
 
@@ -371,6 +379,9 @@ def init_instrumentations(
         elif instrument == Instruments.COHERE:
             if init_cohere_instrumentor():
                 instrument_set = True
+        elif instrument == Instruments.CREW:
+            if init_crewai_instrumentor():
+                instrument_set = True
         elif instrument == Instruments.GOOGLE_GENERATIVEAI:
             if init_google_generativeai_instrumentor():
                 instrument_set = True
@@ -443,6 +454,9 @@ def init_instrumentations(
         elif instrument == Instruments.WEAVIATE:
             if init_weaviate_instrumentor():
                 instrument_set = True
+        elif instrument == Instruments.MCP:
+            if init_mcp_instrumentor():
+                instrument_set = True
         else:
             print(Fore.RED + f"Warning: {instrument} instrumentation does not exist.")
             print(
@@ -584,7 +598,7 @@ def init_chroma_instrumentor():
 
 def init_google_generativeai_instrumentor():
     try:
-        if is_package_installed("google.generativeai"):
+        if is_package_installed("google-generativeai"):
             Telemetry().capture("instrumentation:gemini:init")
             from opentelemetry.instrumentation.google_generativeai import (
                 GoogleGenerativeAiInstrumentor,
@@ -868,7 +882,7 @@ def init_vertexai_instrumentor():
 def init_watsonx_instrumentor():
     try:
         if is_package_installed("ibm-watsonx-ai") or is_package_installed(
-            "ibm-watson-machine-learning"
+            "ibm_watson_machine_learning"
         ):
             Telemetry().capture("instrumentation:watsonx:init")
             from opentelemetry.instrumentation.watsonx import WatsonxInstrumentor
@@ -988,6 +1002,42 @@ def init_groq_instrumentor():
         return False
 
 
+def init_crewai_instrumentor():
+    try:
+        if is_package_installed("crewai"):
+            Telemetry().capture("instrumentation:crewai:init")
+            from opentelemetry.instrumentation.crewai import CrewAIInstrumentor
+
+            instrumentor = CrewAIInstrumentor(
+                exception_logger=lambda e: Telemetry().log_exception(e),
+            )
+            if not instrumentor.is_instrumented_by_opentelemetry:
+                instrumentor.instrument()
+        return True
+    except Exception as e:
+        logging.error(f"Error initializing CrewAI instrumentor: {e}")
+        Telemetry().log_exception(e)
+        return False
+
+
+def init_mcp_instrumentor():
+    try:
+        if is_package_installed("mcp"):
+            Telemetry().capture("instrumentation:mcp:init")
+            from opentelemetry.instrumentation.mcp import McpInstrumentor
+
+            instrumentor = McpInstrumentor(
+                exception_logger=lambda e: Telemetry().log_exception(e),
+            )
+            if not instrumentor.is_instrumented_by_opentelemetry:
+                instrumentor.instrument()
+        return True
+    except Exception as e:
+        logging.error(f"Error initializing MCP instrumentor: {e}")
+        Telemetry().log_exception(e)
+        return False
+
+
 def metrics_common_attributes():
     common_attributes = {}
     workflow_name = get_value("workflow_name")
